@@ -1,6 +1,9 @@
-#' @title Bar plot of the relative gene expression (RE) from the \code{qpcrANOVA} output of a a three-factorial experiment data
-#' @description Bar plot of the relative expression (RE) of a gene along with the confidence interval and significance
+#' @title Bar plot of the relative gene expression (\eqn{\Delta C_T} method) from the \code{qpcrANOVARE} output of a a three-factorial experiment data
+#' 
+#' @description Bar plot of the relative expression (\eqn{\Delta C_T} method) of a gene along with the confidence interval and significance
+#' 
 #' @details The \code{threeFACTORplot} function generates the bar plot of the average fold change for target genes along with the significance, standard error (se) and the 95\% confidence interval (ci).
+#' 
 #' @author Ghader Mirzaghaderi
 #' @export threeFACTORplot
 #' @import tidyr
@@ -8,7 +11,7 @@
 #' @import reshape2
 #' @import ggplot2
 #' @import agricolae
-#' @param res the FC data frame created by \code{qpcrANOVA(x)$Result} function on a three factorial data such as \code{data_3factor} example data frame.
+#' @param res the FC data frame created by \code{qpcrANOVARE(x)$Result} function on a three factorial data such as \code{data_3factor} example data frame.
 #' @param arrangement order based on the columns in the output table (e.g. c(2,3,1) or c(1,3,2)) affecting factor arrangement of the output graph.
 #' @param bar.width a positive number determining bar width.
 #' @param fill  a color vector specifying the fill color for the columns of the bar plot. One of the palettes in \code{\link[RColorBrewer]{display.brewer.all}} (e.g. "Reds" or "Blues", ...) can be applied.
@@ -32,7 +35,7 @@
 #' data_3factor
 #'
 #' # Before plotting, the result needs to be extracted as below:
-#' res <- qpcrANOVA(data_3factor, numberOfrefGenes = 1)$Result
+#' res <- qpcrANOVARE(data_3factor, numberOfrefGenes = 1)$Result
 #' res
 #'
 #' # Arrange the first three colunms of the result table.
@@ -102,7 +105,7 @@ threeFACTORplot <- function(res,
                          legend.title = "Legend Title",
                          legend.position = c(0.4, 0.8),
                          fontsize = 12,
-                         fontsizePvalue = 7,
+                         fontsizePvalue = 5,
                          show.letters = TRUE,
                          axis.text.x.angle = 0,
                          axis.text.x.hjust = 0.5){
@@ -116,7 +119,7 @@ threeFACTORplot <- function(res,
   
   if (any(grepl("RE", names(x)))) {
     RE <- x$RE
-  
+    if(errorbar == "se") {
   pp1 <- ggplot(x, aes(x[,1], y = RE, fill = x[,2])) +
     geom_bar(stat = "identity", position = "dodge", width =  bar.width, col = "black") +
     geom_errorbar(aes(ymax = RE + se, ymin = RE),
@@ -152,10 +155,8 @@ threeFACTORplot <- function(res,
     pp1 <- pp1 +
       xlab(xlab)
   }
-  
-  
-  
-  pp2 <- ggplot(x, aes(x[,1], y = RE, fill = x[,2])) +
+  } else if(errorbar == "ci") {
+  pp1 <- ggplot(x, aes(x[,1], y = RE, fill = x[,2])) +
     geom_bar(stat = "identity", position = "dodge", width =  bar.width, col = "black") +
     geom_errorbar(aes(ymin = LCL, ymax = UCL),
                   position = position_dodge(bar.width), width = 0.15, color = "black") +
@@ -178,37 +179,43 @@ threeFACTORplot <- function(res,
     theme(strip.text = element_text(size = fontsize))
   
   if (show.letters) {
-    pp2 <- pp2 +
+    pp1 <- pp1 +
       geom_text(data = x, aes(label=letters, y = UCL + letter.position.adjust), color = "black",
                 show.legend = FALSE, position = position_dodge(bar.width), size = fontsizePvalue)
   }
   
   if(xlab == "none"){
-    pp2 <- pp2 + 
+    pp1 <- pp1 + 
       labs(x = NULL)
   }else{
-    pp2 <- pp2 +
+    pp1 <- pp1 +
       xlab(xlab)
   }
+  } 
   
-  
-  if(errorbar == "se") {
-    out <- list(plot = pp1)
-    
-  } else if(errorbar == "ci") {
-    out <- list(plot = pp2)
-  }
+  # if(errorbar == "se") {
+  #   out <- list(plot = pp1)
+  #   
+  # } else if(errorbar == "ci") {
+  #   out <- list(plot = pp1)
+  # }
   }
 
   
   
   
   
+  
+  
+  
+  
+  
+  
+  
   if (any(grepl("FC", names(x)))) {
-    x$FC <- as.numeric(x$FC)
     letters <- x$sig
     FC <- x$FC
-    
+    if(errorbar == "se") {
     pp1 <- ggplot(x, aes(x[,1], y = FC, fill = x[,2])) +
       geom_bar(stat = "identity", position = "dodge", width =  bar.width, col = "black") +
       geom_errorbar(aes(ymax = FC + se, ymin = FC),
@@ -244,10 +251,8 @@ threeFACTORplot <- function(res,
       pp1 <- pp1 +
         xlab(xlab)
     }
-    
-    
-    
-    pp2 <- ggplot(x, aes(x[,1], y = FC, fill = x[,2])) +
+    } else if(errorbar == "ci") {
+    pp1 <- ggplot(x, aes(x[,1], y = FC, fill = x[,2])) +
       geom_bar(stat = "identity", position = "dodge", width =  bar.width, col = "black") +
       geom_errorbar(aes(ymin = LCL, ymax = UCL),
                     position = position_dodge(bar.width), width = 0.15, color = "black") +
@@ -270,29 +275,29 @@ threeFACTORplot <- function(res,
       theme(strip.text = element_text(size = fontsize))
     
     if (show.letters) {
-      pp2 <- pp2 +
+      pp1 <- pp1 +
         geom_text(data = x, aes(label=letters, y = UCL + letter.position.adjust), color = "black",
                   show.legend = FALSE, position = position_dodge(bar.width), size = fontsizePvalue)
     }
     
     if(xlab == "none"){
-      pp2 <- pp2 + 
+      pp1 <- pp1 + 
         labs(x = NULL)
     }else{
-      pp2 <- pp2 +
+      pp1 <- pp1 +
         xlab(xlab)
     }
+    } 
     
-    
-    if(errorbar == "se") {
-      out <- list(plot = pp1)
-      
-    } else if(errorbar == "ci") {
-      out <- list(plot = pp2)
-    }
+    # if(errorbar == "se") {
+    #   out <- list(plot = pp1)
+    #   
+    # } else if(errorbar == "ci") {
+    #   out <- list(plot = pp1)
+    # }
   }
   
   
   
-  return(out)
+  return(pp1)
 }
