@@ -1,6 +1,9 @@
-#' @title Bar plot of the relative gene expression (RE) from the \code{qpcrANOVA} output of a two-factorial experiment data
-#' @description Bar plot of the relative expression (RE) of a gene along with the standard error (se), 95\% confidence interval (ci) and significance
+#' @title Bar plot of the relative gene expression (\eqn{\Delta C_T} method) from the \code{qpcrANOVARE} output of a two-factorial experiment data
+#' 
+#' @description Bar plot of the relative expression (\eqn{\Delta C_T} method) of a gene along with the standard error (se), 95\% confidence interval (ci) and significance
+#' 
 #' @details The \code{twoFACTORplot} function generates the bar plot of the average fold change for target genes along with the significance, standard error (se) and the 95\% confidence interval (ci) as error bars.
+#' 
 #' @author Ghader Mirzaghaderi
 #' @export twoFACTORplot
 #' @import tidyr
@@ -8,7 +11,7 @@
 #' @import reshape2
 #' @import ggplot2
 #' @import agricolae
-#' @param res the FC data frame created by \code{qpcrANOVA(x)$Result} function on a two factor data such as \code{data_2factor}.
+#' @param res the FC data frame created by \code{qpcrANOVARE(x)$Result} function on a two factor data such as \code{data_2factor}.
 #' @param x.axis.factor x-axis factor.
 #' @param group.factor grouping factor.
 #' @param width a positive number determining bar width.
@@ -33,7 +36,7 @@
 #' data_2factor
 #'
 #' # Before generating plot, the result table needs to be extracted as below:
-#' res <- qpcrANOVA(data_2factor, numberOfrefGenes = 1)$Result
+#' res <- qpcrANOVARE(data_2factor, numberOfrefGenes = 1)$Result
 #'
 #' # Plot of the 'res' data with 'Genotype' as grouping factor
 #' twoFACTORplot(res,
@@ -48,6 +51,7 @@
 #'    letter.position.adjust = 0.2,
 #'    legend.position = c(0.2, 0.8),
 #'    errorbar = "se")
+#'    
 #'
 #' # Plotting the same data with 'Drought' as grouping factor
 #' twoFACTORplot(res,
@@ -57,6 +61,28 @@
 #'               fill = "Blues",
 #'               fontsizePvalue = 5,
 #'               errorbar = "ci")
+#'               
+#'               
+#'               
+#' # Combining FC results of two different genes:
+#' a <- qpcrREPEATED(data_repeated_measure_1,
+#'                   numberOfrefGenes = 1,
+#'                   factor = "time")
+#' 
+#' b <- qpcrREPEATED(data_repeated_measure_2,
+#'                   factor = "time",
+#'                   numberOfrefGenes = 1)
+#' 
+#' a1 <- a$FC_statistics_of_the_main_factor
+#' b1 <- b$FC_statistics_of_the_main_factor
+#' c <- rbind(a1, b1)
+#' c$gene <- factor(c(1,1,1,2,2,2))
+#' c
+#' 
+#' twoFACTORplot(c, x.axis.factor = contrast, 
+#'               group.factor = gene, fill = 'Reds',
+#'               ylab = "FC", axis.text.x.angle = 45,
+#'               axis.text.x.hjust = 1)
 #'
 #'
 
@@ -78,7 +104,7 @@ twoFACTORplot <- function(res,
                           xlab = "none",
                           legend.position = c(0.09, 0.8),
                           fontsize = 12,
-                          fontsizePvalue = 7,
+                          fontsizePvalue = 5,
                           axis.text.x.angle = 0,
                           axis.text.x.hjust = 0.5){
   b <- res
@@ -89,7 +115,7 @@ twoFACTORplot <- function(res,
   
   if (any(grepl("RE", names(b)))) {
     RE <- b$RE
-    
+    if(errorbar == "se") { 
   qq1 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
                        y = RE, group = {{ group.factor }}, fill = {{ group.factor }})) +
     geom_col(color = "black", position = "dodge", width = width) +
@@ -127,9 +153,8 @@ twoFACTORplot <- function(res,
     qq1 <- qq1 +
       xlab(xlab)
   }
-  
-  
-  qq2 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
+    } else if(errorbar == "ci") {
+  qq1 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
                        y = RE, group = {{ group.factor }}, fill = {{ group.factor }})) +
     geom_col(color = "black", position = "dodge", width = width) +
     scale_fill_brewer(palette = fill) +
@@ -148,32 +173,32 @@ twoFACTORplot <- function(res,
   
   
   if (show.errorbars) {
-    qq2 <-qq2 +
+    qq1 <-qq1 +
       geom_errorbar(aes(ymin = LCL, ymax = UCL), width = 0.2, position = position_dodge(width = 0.5))
   }
   
 
   if (show.letters) {
-    qq2 <- qq2 + 
+    qq1 <- qq1 + 
       geom_text(data = b, aes(label = letters, x = {{ x.axis.factor }}, y = UCL + letter.position.adjust), 
                 vjust = -0.5, size = fontsizePvalue, position = position_dodge(width = 0.5))
   }
   
   if(xlab == "none"){
-    qq2 <- qq2 + 
+    qq1 <- qq1 + 
       labs(x = NULL)
   }else{
-    qq2 <- qq2 +
+    qq1 <- qq1 +
       xlab(xlab)
   }
+    }
   
-  
-  if(errorbar == "se") {
-    out2 <- list(plot = qq1)
-    
-  } else if(errorbar == "ci") {
-    out2 <- list(plot = qq2)
-  }
+  # if(errorbar == "se") {
+  #   out2 <- list(plot = qq1)
+  #   
+  # } else if(errorbar == "ci") {
+  #   out2 <- list(plot = qq1)
+  # }
   }
   
   
@@ -183,10 +208,9 @@ twoFACTORplot <- function(res,
   
   
   if (any(grepl("FC", names(b)))) {
-    x$FC <- as.numeric(x$FC)
-    letters <- x$sig
+    letters <- b$sig
     FC <- b$FC
-    
+    if(errorbar == "se") {
     qq1 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
                          y = FC, group = {{ group.factor }}, fill = {{ group.factor }})) +
       geom_col(color = "black", position = "dodge", width = width) +
@@ -224,9 +248,8 @@ twoFACTORplot <- function(res,
       qq1 <- qq1 +
         xlab(xlab)
     }
-    
-    
-    qq2 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
+    } else if(errorbar == "ci") {
+    qq1 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
                          y = FC, group = {{ group.factor }}, fill = {{ group.factor }})) +
       geom_col(color = "black", position = "dodge", width = width) +
       scale_fill_brewer(palette = fill) +
@@ -245,36 +268,31 @@ twoFACTORplot <- function(res,
     
     
     if (show.errorbars) {
-      qq2 <-qq2 +
+      qq1 <-qq1 +
         geom_errorbar(aes(ymin = LCL, ymax = UCL), width = 0.2, position = position_dodge(width = 0.5))
     }
     
     
     if (show.letters) {
-      qq2 <- qq2 + 
+      qq1 <- qq1 + 
         geom_text(data = b, aes(label = letters, x = {{ x.axis.factor }}, y = UCL + letter.position.adjust), 
                   vjust = -0.5, size = fontsizePvalue, position = position_dodge(width = 0.5))
     }
     
     if(xlab == "none"){
-      qq2 <- qq2 + 
+      qq1 <- qq1 + 
         labs(x = NULL)
     }else{
-      qq2 <- qq2 +
+      qq1 <- qq1 +
         xlab(xlab)
     }
+    }  
     
-    
-    if(errorbar == "se") {
-      out2 <- list(plot = qq1)
-      
-    } else if(errorbar == "ci") {
-      out2 <- list(plot = qq2)
-    }
+
   }
   
   
-  return(out2)
+  return(qq1)
 }
 
 
